<?php namespace App\Models\Admin;

use App\Models\Project\DatatableModel;

class BlogModel extends AdminModel{
	private $table; 
	
    public function __construct(){
		parent::__construct();
		$this->table = "blog";
    }

	public function get_datatable(){
		$dtObj = new DatatableModel($this->db);
		$dtObj->set_table($this->table." AS b");
		// Set Datatable columns 
		$dtObj->set_column('b.blog_id', 'desc|sort|search', 'RecordID');
		$dtObj->set_column('b.blog_url', '');
		$dtObj->set_column('b.publish_date', '');
		$dtObj->set_column('b.status', 'sort|search');
		$dtObj->set_column('bl.title', 'sort|search');
		$builder = $dtObj->get_builder();
		$builder->join($this->table."_ln AS bl","b.blog_id=bl.blog_id AND bl.language_code='".$this->project->default_lang_code."'",'left');
		$builder->where('b.is_deleted','No');
		return $dtObj->get_data($builder);
	} 
	
	public function get($language_list,$blog_id){
		$builder = $this->db->table($this->table." AS mt");
		$columns = ["mt.*"];
		$ln_columns = ['blog_ln_id',
			'title',
			'short_description',
			'description',
			'meta_title',
			'meta_keywords',
			'meta_description',
			'publisher_name',
			'language_code'];
		if($language_list){
			foreach($language_list as $language){
				foreach($ln_columns as $col_name){
					array_push($columns,$language['code'].".".$col_name." AS ".$col_name."_".$language['code']);
				}
				$builder->join($this->table."_ln AS ".$language['code'],"mt.blog_id=".$language['code'].".blog_id AND ".$language['code'].".language_code='".$language['code']."'",'left');
			}
		}
		$builder->select(implode(", ",$columns));
		$builder->where('mt.blog_id',$blog_id);
		$query = $builder->get();
		//echo $builder->getCompiledSelect();
		$rec = $query->getRowArray();
		if($rec){
			$rec['publish_date'] = date('d-m-Y',strtotime($rec['publish_date']));
			$rec['publish_time'] = date('h:i A',strtotime($rec['publish_time']));
		}
		return $rec;
	}
	
	public function insert($data){
		$this->add_insert_log($data);
		$builder = $this->db->table($this->table);
		$builder->insert($data);
		return $this->db->insertID();
	}
	
	public function update($data, $blog_id){
		$this->add_update_log($data);
		$builder = $this->db->table($this->table);
		$builder->where('blog_id',$blog_id);
		$builder->update($data);
	}
	
	public function delete($blog_id){
		$data['is_deleted'] = "Yes";
		$this->add_update_log($data);
		$builder = $this->db->table($this->table);
		$builder->where('blog_id',$blog_id)
				->update($data);
	}
	
	public function is_unique_blog_url($url,$blog_id){
		$builder = $this->db->table($this->table);
		$builder->where('is_deleted','No')
			->where('blog_url',$url);
		if($blog_id!=""){
			$builder->where('blog_id!=',$blog_id);
		}
		$query = $builder->get();
		if($query->getRowArray()){
			$response = "FALSE|The blog url already exist!";
		}else{
			$response = "TRUE|";
		}
		return $response;
	}
	
	public function update_language_data($data,$blog_ln_id){
		$builder = $this->db->table($this->table.'_ln');
		$builder->where('blog_ln_id',$blog_ln_id)
		->update($data);
	}
	
	public function insert_language_data($data){
		$builder = $this->db->table($this->table.'_ln');
		$builder->insert($data);
	}
}