<?php namespace App\Models\Admin;

use App\Models\Project\DatatableModel;

class DownloadCategoryModel extends AdminModel{
	private $table; 
	
    public function __construct(){
		parent::__construct();
		$this->table = "download_category";
    }

	public function get_datatable(){
		$dtObj = new DatatableModel($this->db);
		$dtObj->set_table($this->table." AS pa");
		// Set Datatable columns 
		$dtObj->set_column('pa.download_category_id', 'desc|sort|search', 'RecordID');
		$dtObj->set_column('pa.download_category_url', '');
		$dtObj->set_column('pa.status', 'sort|search');
		$dtObj->set_column('pal.title', 'sort|search');
		$builder = $dtObj->get_builder();
		$builder->join($this->table."_ln AS pal","pa.download_category_id=pal.download_category_id AND pal.language_code='".$this->project->default_lang_code."'",'left');
		$builder->where('pa.is_deleted','No');
		return $dtObj->get_data($builder);
	} 
	
	public function get($language_list,$download_category_id){
		$builder = $this->db->table($this->table." AS mt");
		$columns = ["mt.*"];
		$ln_columns = ['download_category_ln_id',
			'title',
			'short_description',
			'description',
			'meta_title',
			'meta_keywords',
			'meta_description',
			'language_code'];
		if($language_list){
			foreach($language_list as $language){
				foreach($ln_columns as $col_name){
					array_push($columns,$language['code'].".".$col_name." AS ".$col_name."_".$language['code']);
				}
				$builder->join($this->table."_ln AS ".$language['code'],"mt.download_category_id=".$language['code'].".download_category_id AND ".$language['code'].".language_code='".$language['code']."'",'left');
			}
		}
		$builder->select(implode(", ",$columns));
		$builder->where('mt.download_category_id',$download_category_id);
		$query = $builder->get();
		//echo $builder->getCompiledSelect();
		return $query->getRowArray();
	}
	
	public function insert($data){
		$this->add_insert_log($data);
		$builder = $this->db->table($this->table);
		$builder->insert($data);
		return $this->db->insertID();
	}
	
	public function update($data, $download_category_id){
		$this->add_update_log($data);
		$builder = $this->db->table($this->table);
		$builder->where('download_category_id',$download_category_id);
		$builder->update($data);
	}
	
	public function delete($download_category_id){
		$data['is_deleted'] = "Yes";
		$this->add_update_log($data);
		$builder = $this->db->table($this->table);
		$builder->where('download_category_id',$download_category_id)
				->update($data);
	}
	
	public function is_unique_download_category_url($url,$download_category_id){
		$builder = $this->db->table($this->table);
		$builder->where('is_deleted','No')
			->where('download_category_url',$url);
		if($download_category_id!=""){
			$builder->where('download_category_id!=',$download_category_id);
		}
		$query = $builder->get();
		if($query->getRowArray()){
			$response = "FALSE|The download_category url already exist!";
		}else{
			$response = "TRUE|";
		}
		return $response;
	}
	
	public function update_language_data($data,$download_category_ln_id){
		$builder = $this->db->table($this->table.'_ln');
		$builder->where('download_category_ln_id',$download_category_ln_id)
		->update($data);
	}
	
	public function insert_language_data($data){
		$builder = $this->db->table($this->table.'_ln');
		$builder->insert($data);
	}
}