<?php namespace App\Controllers\Admin;

class Blog extends AdminController
{
	private $mObj;
	private $write_path; 
	
	public function __construct(){		
        $this->mObj = model('App\Models\Admin\BlogModel');
		$this->menu_id = 27;
		$this->write_path = ROOTPATH . 'public/uploads/';		
    }
	
	public function index(){
		$this->allowed('is_list');
		$data['footer_includes'] = ['blog_list_js'];		
		echo $this->view_inner_template('blog_list',$data);
	}
	
	public function ajax_list(){
		$this->allowed('is_list');
		$result = $this->mObj->get_datatable();
		$output = array(
			"meta" => $result['meta'],
            "data" => $result['data']
        );
        
        // Output to JSON format
        echo json_encode($output);
	}
	 
	public function add(){
		$this->allowed('is_add');
		$data['form_heading'] = "Add Blog/Media";
		$data['action'] = "add";
		$data['language_list'] = $this->cmObj->get_language_list();
		
		if($this->request->getMethod() === 'post'){
			$rules = $this->get_validation_rules($data['language_list']);
			if($this->validate($rules)) { 
				$data_in = $this->get_column_values();
				$id = $this->mObj->insert($data_in);
				$this->save_language_data($data['language_list'],$id);
				$this->notify_success('Record Added Successfully');
				return redirect()->to(get_admin_path('blog'));
			}
		}
		$data['footer_includes'] = ['blog_add_edit_js'];	
		echo $this->view_inner_template('blog_add_edit',$data);
	}
	
	public function edit($blog_id){
		$this->allowed('is_edit');
		$data['form_heading'] = "Edit Blog/Media";
		$data['action'] = "edit";
		$data['language_list'] = $this->cmObj->get_language_list();
		
		if($this->request->getMethod() === 'post'){
			$rules = $this->get_validation_rules($data['language_list'],$blog_id);
			if ($this->validate($rules)) { 
				$data_in = $this->get_column_values();
				$this->mObj->update($data_in,$blog_id);
				$this->save_language_data($data['language_list'],$blog_id);
				$this->remove_prev_file($data_in);
				$this->notify_success('Record Updated Successfully');
				return redirect()->to(get_admin_path('blog'));
			}
		}else{
			$data['update_data'] = $this->mObj->get($data['language_list'],$blog_id);
		}
		$data['footer_includes'] = ['blog_add_edit_js'];	
		echo $this->view_inner_template('blog_add_edit',$data);
	}
	
	private function remove_prev_file($data_in){
		if(isset($data_in['photo_image']) && 
			$data_in['photo_image']!="" && 
			$this->request->getPost('uploaded_photo_image')!="" &&
			$data_in['photo_image']!=$this->request->getPost('uploaded_photo_image') && 
			file_exists($this->write_path.$this->request->getPost('uploaded_photo_image'))){
			unlink($this->write_path.$this->request->getPost('uploaded_photo_image'));
		}
	}
	
	public function delete($blog_id){
		$this->allowed('is_edit');
		$this->mObj->delete($blog_id);
		$this->notify_success('Record Deleted Successfully');
		return redirect()->to(get_admin_path('blog'));
	}
	
	private function get_column_values(){
		$data['blog_url'] = $this->request->getPost('blog_url');
		$data['status'] = $this->request->getPost('status');
		$data['blog_type'] = $this->request->getPost('blog_type');
		$data['publish_date'] = date('Y-m-d H:i:s', strtotime($this->request->getPost('publish_date')));
		$data['publish_time'] = date('H:i:s',strtotime($this->request->getPost('publish_time')));
		
		$this->save_uploaded_file($data);
		return $data;
	}
	// .' '.$this->request->getPost('publish_time')));
	private function get_validation_rules($language_list,$record_id=""){
		if($language_list){
			foreach($language_list as $language){
				$rules['title_'.$language['code']] = ['label'=>'Title', 'rules' => 'trim|required'];
				$rules['meta_title_'.$language['code']] = ['label'=>'Meta Title', 'rules' => 'trim|required'];
				$rules['meta_keywords_'.$language['code']] = ['label'=>'Meta Keywords', 'rules' => 'trim|required'];
				$rules['meta_description_'.$language['code']] = ['label'=>'Meta Description', 'rules' => 'trim|required'];
				//$rules['short_description_'.$language['code']] = ['label'=>'Short Description', 'rules' => 'trim|required'];
				$rules['description_'.$language['code']] = ['label'=>'Description', 'rules' => 'trim|required'];
				$rules['publisher_name_'.$language['code']] = ['label'=>'Publisher Name', 'rules' => 'trim|required'];
			}
		}
		
		$rules['blog_url'] = ['label'=>'Blog URL', 'rules' => 'trim|required|pr_callback['.$this->mObj->is_unique_blog_url($this->request->getPost('blog_url'),$record_id).']'];
		$rules['blog_type'] = ['label'=>'Blog Type', 'rules' => 'trim|required'];
		$rules['status'] = ['label'=>'Status', 'rules' => 'trim|required'];
		$rules['publish_date'] = ['label'=>'Publish Date', 'rules' => 'trim|required'];
		$rules['publish_time'] = ['label'=>'Publish Date', 'rules' => 'trim|required'];
				
		return $rules;
	}
	
	private function save_uploaded_file(&$data){
		$file = $this->request->getFile('photo_image');
		if($file->getName()){
			$file->move(ROOTPATH . 'public/uploads/',$file->getRandomName());
			$data['photo_image'] = $file->getName();
		}
	}
	
	public function save_language_data($language_list,$id=""){
		if($language_list){			
			foreach($language_list as $language){
				$data = [];
				$data['title'] = $this->request->getPost('title_'.$language['code']);
				$data['meta_title'] = $this->request->getPost('meta_title_'.$language['code']);
				$data['meta_keywords'] = $this->request->getPost('meta_keywords_'.$language['code']);
				$data['meta_description'] = $this->request->getPost('meta_description_'.$language['code']);
				$data['short_description'] = $this->request->getPost('short_description_'.$language['code']);
				$data['description'] = $this->request->getPost('description_'.$language['code']);
				$data['publisher_name'] = $this->request->getPost('publisher_name_'.$language['code']);
				$data['language_code'] = $language['code'];
				if($this->request->getPost('blog_ln_id_'.$language['code'])){
					$this->mObj->update_language_data($data,$this->request->getPost('blog_ln_id_'.$language['code']));
				}else{
					$data['blog_id'] = $id;
					$this->mObj->insert_language_data($data);
				}
			}
		}
	}
}