<?php namespace App\Models\Admin;

use App\Models\Project\DatatableModel;

class Video_albumModel extends AdminModel{
	private $table;
	
    public function __construct(){
		parent::__construct();
		$this->table = "video_album";
    }
	
	public function get_datatable(){
		$dtObj = new DatatableModel($this->db);
		$dtObj->set_table($this->table." AS pa");
		// Set Datatable columns 
		$dtObj->set_column('pa.video_album_id', 'desc|sort|search', 'RecordID');
		$dtObj->set_column('pal.title', 'sort|search');
		$dtObj->set_column('pa.status', 'sort|search');
		$builder = $dtObj->get_builder();
		$builder->where('pa.is_deleted','No');
		$builder->join($this->table."_ln AS pal","pa.video_album_id=pal.video_album_id AND pal.language_code='".$this->project->default_lang_code."'",'left');
		return $dtObj->get_data($builder);
	}
	
	public function get($language_list,$video_album_id){
		$builder = $this->db->table($this->table." AS mt");
		$columns = ["mt.*"];
		$ln_columns = ['video_album_ln_id',
			'title',
			'meta_title',
			'meta_keywords',
			'meta_description',
			'language_code'];
		if($language_list){
			foreach($language_list as $language){
				foreach($ln_columns as $col_name){
					array_push($columns,$language['code'].".".$col_name." AS ".$col_name."_".$language['code']);
				}
				$builder->join($this->table."_ln AS ".$language['code'],"mt.video_album_id=".$language['code'].".video_album_id AND ".$language['code'].".language_code='".$language['code']."'",'left');
			}
		}
		$builder->select(implode(", ",$columns));
		$builder->where('mt.video_album_id',$video_album_id);
		$query = $builder->get();
		//echo $builder->getCompiledSelect();
		return $query->getRowArray();
	}
	
	public function insert($data){
		$this->add_insert_log($data);
		$builder = $this->db->table($this->table);
		$builder->insert($data);
		return $this->db->insertID();
	}
	
	public function update($data, $id){
		$this->add_update_log($data);
		$builder = $this->db->table($this->table);
		$builder->where('video_album_id',$id);
		$builder->update($data);
	}
	
	public function delete($video_album_id){
		$data['is_deleted'] = "Yes";
		$this->add_update_log($data);
		$builder = $this->db->table($this->table);
		$builder->where('video_album_id',$video_album_id)
				->update($data);
	}
	
	public function update_language_data($data,$video_album_ln_id){
		$builder = $this->db->table($this->table.'_ln');
		$builder->where('video_album_ln_id',$video_album_ln_id)
		->update($data);
	}
	
	public function insert_language_data($data){
		$builder = $this->db->table($this->table.'_ln');
		$builder->insert($data);
	}
	
	public function is_unique_video_album_url($video_album_url,$video_album_id){
		$builder = $this->db->table($this->table);
		$builder->where('is_deleted','No')
				->where('video_album_url',$video_album_url);
		if($video_album_id){
			$builder->where('video_album_id!=',$video_album_id);
		}
		$query = $builder->get();
		if($query->getRowArray()){
			$response = "FALSE|The Video Album Url already exist!";
		}else{
			$response = "TRUE|";
		}
		return $response;
	} 
	
	public function is_unique_title($title,$id){
		$builder = $this->db->table("video_album_ln AS pal");		
		$builder->join("video_album AS pa","pa.video_album_id=pal.video_album_id",'inner')
				->where('pa.is_deleted','No')
				->where('pal.title',$title);
		if($id!=""){
			$builder->where('pal.video_album_id!=',$id);
		}
		$query = $builder->get();
		if($query->getRowArray()){
			$response = "FALSE|The Title already exist!";
		}else{
			$response = "TRUE|";
		}
		return $response;
	}
}